DerivationPath

Struct DerivationPath 

pub struct DerivationPath(/* private fields */);
A key derivation path

Implementations

Source

impl DerivationPath

pub fn has_transparent_compatible_coin_type(&self, scheme: SchemeType) -> bool

Check if the path has a compatible transparent coin type

pub fn has_shielded_compatible_coin_type(&self) -> bool

Check if the path has a compatible shielded coin type

pub fn is_bip44_conform(&self, strict: bool) -> bool

pub fn is_slip10_conform(&self, scheme: SchemeType) -> bool

pub fn is_zip32_conform(&self) -> bool

Check if the path is ZIP-0032 conform https://zips.z.cash/zip-0032#sapling-key-path

pub fn is_namada_transparent_compliant(&self, scheme: SchemeType) -> bool

Check if the path is compliant with Namada’s transparent scheme

pub fn is_namada_shielded_compliant(&self) -> bool

Check if the path is compliant with Namada’s shielded scheme

pub fn modified_zip32() -> (Self, SchemeType)

Modified ZIP32 path is used to derive Ed25519 keys to derive shielded keys in way that’s compatible with the Ledger device app, in which the pure ZIP32 cannot be used because its secret is inaccessible.

pub fn default_for_transparent_scheme(scheme: SchemeType) -> Self

A default derivation path for transparent scheme

pub fn default_for_shielded() -> Self

A default derivation path for shielded scheme

pub fn from_path_string(path: &str) -> Result<Self, DerivationPathError>

Try to parse a derivation path from a string

pub fn from_path_string_for_transparent_scheme( scheme: SchemeType, path: &str, ) -> Result<Self, DerivationPathError>

Try to parse a derivation path for transparent scheme from a string

pub fn path(&self) -> &[ChildIndex]

Get a reference to the path’s list of ChildIndex items