Provides functionality for managing keys and addresses for a user
Re-exports
pub use pre_genesis::gen_key_to_store;pub use store::AddressVpType;pub use store::Store;pub use self::store::ConfirmationResponse;pub use self::store::ValidatorData;pub use self::store::ValidatorKeys;
Modules
- alias
- Wallet address and key aliases.
- pre_
genesis - Provides functionality for managing validator keys
- store
- Wallet Store information
- test_
utils
Structs
- Dated
Keypair - A keypair with a block height after which it was created
- Derivation
Path - A key derivation path
- Store
Spending Key - Extended spending key with Borsh serialization compatible with DatedSpendingKey. This is necessary to facilitate reading the old Store format.
- Wallet
- Represents a collection of keys and addresses while caching key decryptions
Enums
- Decryption
Error - Derivation
Path Error - Find
KeyError - The error that is produced when a given key cannot be obtained
- Load
Store Error - Errors of wallet loading and storing
- Stored
Keypair - A keypair stored in a wallet
Traits
- Wallet
Io - Captures the interactive parts of the wallet’s functioning
- Wallet
Storage - Captures the permanent storage parts of the wallet’s functioning
Functions
- gen_
secret_ key - Generate a new secret key.
Type Aliases
- Dated
Spending Key - Type alias for a spending key with a birthday.
- Dated
Viewing Key - Type alias for a viewing key with a birthday.